==> pgfouine-0.5.tar.gz: pgfouine-0.5/include/postgresql/postgresql.lib.php <==
<?php

/*
 * This file is part of pgFouine.
 * 
 * pgFouine - a PostgreSQL log analyzer
 * Copyright (c) 2005-2006 Guillaume Smet
 *
 * pgFouine is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * pgFouine is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with pgFouine; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 */

require_once('PostgreSQLAccumulator.class.php');

// regexps
include_once('PostgreSQLRegexps.lib.php');

// lines
require_once('lines/PostgreSQLLogLine.class.php');
require_once('lines/PostgreSQLDurationLine.class.php');
require_once('lines/PostgreSQLQueryStartLine.class.php');
require_once('lines/PostgreSQLQueryStartWithDurationLine.class.php');
require_once('lines/PostgreSQLContinuationLine.class.php');
require_once('lines/PostgreSQLDetailLine.class.php');
require_once('lines/PostgreSQLContextLine.class.php');
require_once('lines/PostgreSQLStatementLine.class.php');
require_once('lines/PostgreSQLErrorLine.class.php');
require_once('lines/PostgreSQLHintLine.class.php');
require_once('lines/PostgreSQLStatusLine.class.php');

// parsers
require_once('parsers/PostgreSQLParser.class.php');
//require_once('parsers/LogPostgreSQLParser.class.php');
require_once('parsers/SyslogPostgreSQLParser.class.php');

?>

==> pgfouine-0.6.tar.gz: pgfouine-0.6/include/postgresql/postgresql.lib.php <==
<?php

/*
 * This file is part of pgFouine.
 * 
 * pgFouine - a PostgreSQL log analyzer
 * Copyright (c) 2005-2006 Guillaume Smet
 *
 * pgFouine is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * pgFouine is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with pgFouine; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 */

require_once('PostgreSQLAccumulator.class.php');

// regexps
include_once('PostgreSQLRegexps.lib.php');

// lines
require_once('lines/PostgreSQLLogLine.class.php');
require_once('lines/PostgreSQLDurationLine.class.php');
require_once('lines/PostgreSQLQueryStartLine.class.php');
require_once('lines/PostgreSQLQueryStartWithDurationLine.class.php');
require_once('lines/PostgreSQLContinuationLine.class.php');
require_once('lines/PostgreSQLDetailLine.class.php');
require_once('lines/PostgreSQLContextLine.class.php');
require_once('lines/PostgreSQLStatementLine.class.php');
require_once('lines/PostgreSQLErrorLine.class.php');
require_once('lines/PostgreSQLHintLine.class.php');
require_once('lines/PostgreSQLStatusLine.class.php');

// parsers
require_once('parsers/PostgreSQLParser.class.php');
require_once('parsers/StderrPostgreSQLParser.class.php');
require_once('parsers/SyslogPostgreSQLParser.class.php');

?>
